@@ -1,5 +1,5 @@
 # JUBE Benchmarking Environment
-# Copyright (C) 2008-2022
+# Copyright (C) 2008-2024
 # Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre
 # http://www.fz-juelich.de/jsc/jube
 #
@@ -363,7 +363,8 @@ class Benchmark(object):
         if show_info:
             LOGGER.info(">>> Analyse finished")
 
-    def create_result(self, only=None, show=False, data_list=None, style=None):
+    def create_result(self, only=None, show=False, data_list=None, style=None,
+                      select=None, exclude=None):
         """Show benchmark result"""
         if only is None:
             only = [result_name for result_name in self._results]
@@ -372,7 +373,7 @@ class Benchmark(object):
         for result_name in self._results_order:
             result = self._results[result_name]
             if result.name in only:
-                result_data = result.create_result_data(style)
+                result_data = result.create_result_data(style, select, exclude)
                 if result.result_dir is None:
                     result_dir = os.path.join(self.bench_dir,
                                               jube2.conf.RESULT_DIRNAME)
@@ -652,6 +653,9 @@ class Benchmark(object):
                     name = workpackage.step.name
                     pool = mp.Pool(processes=procs)
 
+                    # save current logfile name to restore logs in the right logfile
+                    current_logfile_name = jube2.log.LOGFILE_NAME
+
                     # add wps to the parallel pool as long as they have the same name
                     while True:
                         pool.apply_async(workpackage.run, args=('p',),
@@ -680,8 +684,7 @@ class Benchmark(object):
                              if file.startswith(log_fname.split('.')[0]) and
                              file != log_fname]
                 filenames.sort(key=lambda o: int(re.split('_|\.', o)[1]))
-                with open(os.path.join(self.bench_dir,
-                                       jube2.conf.LOGFILE_RUN_NAME), 'a') as outfile:
+                with open(current_logfile_name, 'a') as outfile:
                     for fname in filenames:
                         with open(os.path.join(self.bench_dir, fname), 'r') as infile:
                             contents = infile.read()
@@ -737,6 +740,9 @@ class Benchmark(object):
         # if possible)
         self._work_stat.update_queues(workpackage)
 
+        #Update workpackage status for jube parameter
+        workpackage.update_status()
+
         if not jube2.conf.HIDE_ANIMATIONS:
             status = self.benchmark_status
             jube2.util.output.print_loading_bar(
