@@ -1,5 +1,5 @@
 # JUBE Benchmarking Environment
-# Copyright (C) 2008-2022
+# Copyright (C) 2008-2024
 # Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre
 # http://www.fz-juelich.de/jsc/jube
 #
@@ -119,7 +119,7 @@ class Parameterset(object):
                 value.sort()
                 return jube2.parameter.TemplateParameter(
                             parameter._name, value, parameter._separator, parameter._type,
-                            parameter._mode, parameter._export,
+                            parameter._mode, parameter._unit, parameter._export,
                             parameter._update_mode, parameter._idx,
                             parameter._eval_helper, parameter._duplicate)
         else:
@@ -131,13 +131,18 @@ class Parameterset(object):
         if this is not the case"""
         if only_duplicate:
             if parameter._duplicate != self._parameters[parameter.name]._duplicate:
+                LOGGER.debug(
+                        "The duplicate options for the parameter {0} are stated at least twice differently leading to undefined behaviour.\n".format(
+                            parameter.name))
                 raise ValueError("The duplicate options for the parameter {0} are stated at least twice differently leading to undefined behaviour.".format(parameter.name))
         else:
             if  parameter._separator != self._parameters[parameter.name]._separator or \
                     parameter._type != self._parameters[parameter.name]._type or \
-                    parameter._update_mode != self._parameters[parameter.name]._update_mode or \
-                    parameter._duplicate != self._parameters[parameter.name]._duplicate:
-                raise ValueError("At least one option for the parameter {0} was defined at least twice differently leading to undefined behaviour.".format(parameter.name))
+                    parameter._update_mode != self._parameters[parameter.name]._update_mode:
+                LOGGER.debug(
+                        "At least one option (separator, type, update_mode) for the parameter {0} was defined at least twice differently leading to undefined behaviour.\n".format(
+                            parameter.name))
+                raise ValueError("At least one option (separator, type, update_mode) for the parameter {0} was defined at least twice differently leading to undefined behaviour.".format(parameter.name))
 
     def add_parameter(self, parameter):
         """Add a new parameter"""
@@ -410,7 +415,7 @@ class Parameter(object):
         re.compile(r"(?<!\$)(?:\$\$)*\$(?!\$)(\{)?(\w+?)(?(1)\}|(?=\W|$))")
 
     def __init__(self, name, value, separator=None, parameter_type="string",
-                 parameter_mode="text", export=False,
+                 parameter_mode="text", unit="", export=False,
                  update_mode=NEVER_MODE, idx=-1, eval_helper=None, duplicate="none"):
         self._name = name
         self._value = value
@@ -420,6 +425,7 @@ class Parameter(object):
             self._separator = separator
         self._type = parameter_type
         self._mode = parameter_mode
+        self._unit = unit
         self._based_on = None
         self._export = export
         self._idx = idx
@@ -432,7 +438,7 @@ class Parameter(object):
 
     @staticmethod
     def create_parameter(name, value, separator=None, parameter_type="string",
-                         selected_value=None, parameter_mode="text",
+                         selected_value=None, parameter_mode="text", unit="",
                          export=False, no_templates=False,
                          update_mode=NEVER_MODE, idx=-1, eval_helper=None,
                          fixed=False, duplicate="none"):
@@ -458,22 +464,22 @@ class Parameter(object):
                jube2.conf.ALLOWED_ADVANCED_MODETYPES)):
             if fixed:
                 result = FixedParameter(name, value, separator, parameter_type,
-                                        parameter_mode, export, update_mode,
+                                        parameter_mode, unit, export, update_mode,
                                         idx, eval_helper, duplicate)
             else:
                 result = StaticParameter(name, value, separator,
-                                         parameter_type, parameter_mode,
+                                         parameter_type, parameter_mode, unit,
                                          export, update_mode, idx, eval_helper, duplicate)
         else:
             result = TemplateParameter(name, values, separator, parameter_type,
-                                       parameter_mode, export, update_mode,
+                                       parameter_mode, unit, export, update_mode,
                                        idx, eval_helper, duplicate)
 
         if selected_value is not None:
             tmp = result
             parameter_mode = "text"
             result = FixedParameter(name, selected_value, separator,
-                                    parameter_type, parameter_mode, export,
+                                    parameter_type, parameter_mode, unit, export,
                                     update_mode, idx, eval_helper, duplicate)
             result.based_on = tmp
         return result
@@ -553,6 +559,11 @@ class Parameter(object):
     def mode(self):
         """Return parameter mode"""
         return self._mode
+        
+    @property
+    def unit(self):
+        """Return unit"""
+        return self._unit
 
     @property
     def value(self):
@@ -661,6 +672,8 @@ class Parameter(object):
             parameter_etree.attrib["mode"] = self._mode
         if self._export:
             parameter_etree.attrib["export"] = "true"
+        if self._unit != "":
+            parameter_etree.attrib["unit"] = self._unit
 
         return parameter_etree
 
@@ -676,10 +689,10 @@ class StaticParameter(Parameter):
     """A StaticParameter can be substituted and evaluated."""
 
     def __init__(self, name, value, separator=None, parameter_type="string",
-                 parameter_mode="text", export=False,
+                 parameter_mode="text", unit="", export=False,
                  update_mode=NEVER_MODE, idx=-1, eval_helper=None, duplicate="none"):
         Parameter.__init__(self, name, value, separator, parameter_type,
-                           parameter_mode, export, update_mode, idx,
+                           parameter_mode, unit, export, update_mode, idx,
                            eval_helper, duplicate)
         self._depending_parameter = \
             set([other_par[1] for other_par in
@@ -789,6 +802,7 @@ class StaticParameter(Parameter):
                                                separator=self._separator,
                                                parameter_type=self._type,
                                                parameter_mode=mode,
+                                               unit=self._unit,
                                                export=self._export,
                                                no_templates=no_templates,
                                                update_mode=self._update_mode,
@@ -806,8 +820,10 @@ class StaticParameter(Parameter):
         """Add missing quotes to jube_wp_envstr if needed"""
         env_str = ""
         for var_name, var_value in re.findall(
-                r"^export (.+?)\s*=\s*(.+?)\s*$", value, re.MULTILINE):
-            if (var_value[0] == "'" and var_value[-1] == "'") or \
+                r"^export (.+?)\s*=\s*?(.+?)?\s*?$", value, re.MULTILINE):
+            if not var_value: # Exporting empty variables
+                env_str += "export {0}=\"\"\n".format(var_name)
+            elif (var_value[0] == "'" and var_value[-1] == "'") or \
                     (var_value[0] == "\"" and var_value[-1] == "\""):
                 env_str += "export {0}={1}\n".format(var_name, var_value)
             else:
@@ -839,6 +855,7 @@ class TemplateParameter(Parameter):
                                            value=value,
                                            separator=self._separator,
                                            parameter_type=self._type,
+                                           unit = self._unit,
                                            export=self._export,
                                            update_mode=self._update_mode,
                                            idx=index, duplicate=self._duplicate)
@@ -853,10 +870,10 @@ class FixedParameter(StaticParameter):
     """
 
     def __init__(self, name, value, separator=None, parameter_type="string",
-                 parameter_mode="text", export=False,
+                 parameter_mode="text", unit="", export=False,
                  update_mode=NEVER_MODE, idx=-1, eval_helper=None, duplicate="none"):
         StaticParameter.__init__(self, name, value, separator, parameter_type,
-                                 parameter_mode, export, update_mode, idx,
+                                 parameter_mode, unit, export, update_mode, idx,
                                  eval_helper, duplicate)
         self._depending_parameter = set()
 
