@@ -1,5 +1,5 @@
 # JUBE Benchmarking Environment
-# Copyright (C) 2008-2022
+# Copyright (C) 2008-2024
 # Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre
 # http://www.fz-juelich.de/jsc/jube
 #
@@ -181,11 +181,11 @@ class Pattern(jube2.parameter.StaticParameter):
         # Unicode conversion
         value = "" + value
 
+        self._unit = unit
+
         jube2.parameter.StaticParameter.__init__(
             self, name, value, parameter_type=content_type,
-            parameter_mode=pattern_mode)
-
-        self._unit = unit
+            parameter_mode=pattern_mode, unit=self._unit)
 
     @property
     def derived(self):
